{% load static %}
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>{{ title|default:"Fakturasjekk" }}</title>
    <link href="{% static "ehf_invoice/invoice.css" %}" rel="stylesheet" type="text/css">
</head>
<body>
{% block content %} {% endblock %}
</body>
</html>